@@ -125,7 +125,7 @@ define([
                             code: '${model}.fit(${fit_featureData})',
                             description: 'Fit Encoder/Scaler to X.',
                             options: [
-                                { name: 'fit_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X' }
+                                { name: 'fit_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X', returnFrameType: 'DataFrame' }
                             ]
                         },
                         'fit_transform': {
@@ -134,13 +134,19 @@ define([
                             code: '${fit_trans_allocate} = ${model}.fit_transform(${fit_trans_featureData})',
                             description: 'Fit Encoder/Scaler to X, then transform X.',
                             options: [
-                                { name: 'fit_trans_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X' },
+                                { name: 'fit_trans_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X', returnFrameType: 'DataFrame' },
                                 { name: 'fit_trans_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'trans' }
                             ]
                         },
                         'transform': {
-                            ...defaultActions['transform'],
-                            description: 'Transform labels to normalized encoding.'
+                            name: 'transform',
+                            label: 'Transform',
+                            code: '${trans_allocate} = ${model}.transform(${trans_featureData})',
+                            description: 'Transform labels to normalized encoding.',
+                            options: [
+                                { name: 'trans_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X', returnFrameType: 'DataFrame' },
+                                { name: 'trans_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'trans' }
+                            ]
                         }
                     }
                     if (modelType != 'ColumnTransformer') {
@@ -152,12 +158,49 @@ define([
                                 code: '${inverse_allocate} = ${model}.inverse_transform(${inverse_featureData})',
                                 description: 'Transform binary labels back to multi-class labels.',
                                 options: [
-                                    { name: 'inverse_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X' },
+                                    { name: 'inverse_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X', returnFrameType: 'DataFrame' },
                                     { name: 'inverse_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'inv_trans' }
                                 ]
                             }
                         }
                     }
+                    if (modelType == 'LabelEncoder') {
+                        actions = {
+                            ...actions,
+                            'fit': {
+                                name: 'fit',
+                                label: 'Fit',
+                                code: '${model}.fit(${fit_featureData})',
+                                description: 'Fit Encoder/Scaler to X.',
+                                options: [
+                                    { name: 'fit_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X',
+                                        columnSelection: 'single', returnFrameType: 'Series' }
+                                ]
+                            },
+                            'fit_transform': {
+                                name: 'fit_transform',
+                                label: 'Fit and transform',
+                                code: '${fit_trans_allocate} = ${model}.fit_transform(${fit_trans_featureData})',
+                                description: 'Fit Encoder/Scaler to X, then transform X.',
+                                options: [
+                                    { name: 'fit_trans_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X',
+                                        columnSelection: 'single', returnFrameType: 'Series' },
+                                    { name: 'fit_trans_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'trans' }
+                                ]
+                            },
+                            'transform': {
+                                name: 'transform',
+                                label: 'Transform',
+                                code: '${trans_allocate} = ${model}.transform(${trans_featureData})',
+                                description: 'Transform labels to normalized encoding.',
+                                options: [
+                                    { name: 'trans_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X',
+                                        columnSelection: 'single', returnFrameType: 'Series' },
+                                    { name: 'trans_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'trans' }
+                                ]
+                            }
+                        }
+                    }
                     if (modelType === 'SMOTE') {
                         actions = {
                             'fit': {
@@ -322,7 +365,7 @@ define([
                                 code: '${model}.fit(${fit_featureData})',
                                 description: 'Fit X into an embedded space.',
                                 options: [
-                                    { name: 'fit_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X' }
+                                    { name: 'fit_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X', returnFrameType: 'DataFrame' }
                                 ]
                             },
                             'fit_transform': {
@@ -331,7 +374,7 @@ define([
                                 code: '${fit_trans_allocate} = ${model}.fit_transform(${fit_trans_featureData})',
                                 description: 'Fit X into an embedded space and return that transformed output.', 
                                 options: [
-                                    { name: 'fit_trans_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X' },
+                                    { name: 'fit_trans_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X', returnFrameType: 'DataFrame' },
                                     { name: 'fit_trans_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'trans' }
                                 ]
                             }
@@ -346,17 +389,17 @@ define([
                                 code: '${model}.fit(${fit_featureData}, ${fit_targetData})',
                                 description: 'Fit the Linear Discriminant Analysis model.',
                                 options: [
-                                    { name: 'fit_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X' },
+                                    { name: 'fit_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X', returnFrameType: 'DataFrame' },
                                     { name: 'fit_targetData', label: 'Target Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'y' }
                                 ]
                             },
                             'fit_transform': {
                                 name: 'fit_transform',
                                 label: 'Fit and transform',
-                                code: '${fit_trans_allocate} = ${model}.fit_transform(${fit_trans_featureData}${fit_trans_targetData})',
+                                code: '${fit_trans_allocate} = ${model}.fit_transform(${fit_trans_featureData}, ${fit_trans_targetData})',
                                 description: 'Fit to data, then transform it.', 
                                 options: [
-                                    { name: 'fit_trans_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X' },
+                                    { name: 'fit_trans_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X', returnFrameType: 'DataFrame' },
                                     { name: 'fit_trans_targetData', label: 'Target Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'y' },
                                     { name: 'fit_trans_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'trans' }
                                 ]
@@ -367,7 +410,7 @@ define([
                                 code: '${pred_allocate} = ${model}.predict(${pred_featureData})',
                                 description: 'Predict class labels for samples in X.',
                                 options: [
-                                    { name: 'pred_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X' },
+                                    { name: 'pred_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X', returnFrameType: 'DataFrame' },
                                     { name: 'pred_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'pred' }
                                 ]
                             },
@@ -377,7 +420,7 @@ define([
                                 code: '${trans_allocate} = ${model}.transform(${trans_featureData})',
                                 description: 'Project data to maximize class separation.',
                                 options: [
-                                    { name: 'trans_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X' },
+                                    { name: 'trans_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X', returnFrameType: 'DataFrame' },
                                     { name: 'trans_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'trans' }
                                 ]
                             }
@@ -391,7 +434,7 @@ define([
                             code: '${model}.fit(${fit_featureData})',
                             description: 'Fit X into an embedded space.',
                             options: [
-                                { name: 'fit_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X' }
+                                { name: 'fit_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X', returnFrameType: 'DataFrame' }
                             ]
                         },
                         'fit_transform': {
@@ -400,7 +443,7 @@ define([
                             code: '${fit_trans_allocate} = ${model}.fit_transform(${fit_trans_featureData})',
                             description: 'Fit the model with X and apply the dimensionality reduction on X.', 
                             options: [
-                                { name: 'fit_trans_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X' },
+                                { name: 'fit_trans_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X', returnFrameType: 'DataFrame' },
                                 { name: 'fit_trans_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'trans' }
                             ]
                         },
@@ -410,7 +453,7 @@ define([
                             code: '${inverse_allocate} = ${model}.inverse_transform(${inverse_featureData})',
                             description: 'Transform data back to its original space.',
                             options: [
-                                { name: 'inverse_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X' },
+                                { name: 'inverse_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X', returnFrameType: 'DataFrame' },
                                 { name: 'inverse_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'inv_trans' }
                             ]
                         },
@@ -420,7 +463,7 @@ define([
                             code: '${trans_allocate} = ${model}.transform(${trans_featureData})',
                             description: 'Apply dimensionality reduction to X.',
                             options: [
-                                { name: 'trans_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X' },
+                                { name: 'trans_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X', returnFrameType: 'DataFrame' },
                                 { name: 'trans_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'trans' }
                             ]
                         }
@@ -510,7 +553,15 @@ define([
                     options: [
                         { name: 'importance_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X_train' },
                         { name: 'importance_targetData', label: 'Target Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'y_train' },
-                        { name: 'scoring', component: ['input'], usePair: true },
+                        { name: 'scoring', component: ['option_suggest'], usePair: true, type: 'text', 
+                            options: [
+                                'explained_variance', 'max_error', 'neg_mean_absolute_error', 'neg_mean_squared_error', 'neg_root_mean_squared_error',
+                                'neg_mean_squared_log_error', 'neg_median_absolute_error', 'r2', 'neg_mean_poisson_deviance', 'neg_mean_gamma_deviance',
+                                'neg_mean_absolute_percentage_error',
+                                'accuracy', 'balanced_accuracy', 'top_k_accuracy', 'average_precision', 'neg_brier_score',
+                                'f1', 'f1_micro', 'f1_macro', 'f1_weighted', 'f1_samples', 'neg_log_loss', 'precision', 'recall', 'jaccard', 
+                                'roc_auc', 'roc_auc_ovr', 'roc_auc_ovo', 'roc_auc_ovr_weighted', 'roc_auc_ovo_weighted'
+                            ] },
                         { name: 'sort', label: 'Sort data', component: ['bool_checkbox'], value: true, usePair: true },
                         { name: 'importance_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'importances' }
                     ]
@@ -524,7 +575,15 @@ define([
                     options: [
                         { name: 'importance_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X_train' },
                         { name: 'importance_targetData', label: 'Target Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'y_train' },
-                        { name: 'scoring', component: ['input'], usePair: true },
+                        { name: 'scoring', component: ['option_suggest'], usePair: true, type: 'text', 
+                            options: [
+                                'explained_variance', 'max_error', 'neg_mean_absolute_error', 'neg_mean_squared_error', 'neg_root_mean_squared_error',
+                                'neg_mean_squared_log_error', 'neg_median_absolute_error', 'r2', 'neg_mean_poisson_deviance', 'neg_mean_gamma_deviance',
+                                'neg_mean_absolute_percentage_error',
+                                'accuracy', 'balanced_accuracy', 'top_k_accuracy', 'average_precision', 'neg_brier_score',
+                                'f1', 'f1_micro', 'f1_macro', 'f1_weighted', 'f1_samples', 'neg_log_loss', 'precision', 'recall', 'jaccard', 
+                                'roc_auc', 'roc_auc_ovr', 'roc_auc_ovo', 'roc_auc_ovr_weighted', 'roc_auc_ovo_weighted'
+                            ] },
                         { name: 'sort', label: 'Sort data', component: ['bool_checkbox'], value: true, usePair: true },
                         { name: 'top_count', label: 'Top count', component: ['input_number'], min: 0, usePair: true }
                     ]
@@ -668,7 +727,44 @@ define([
                                 { name: 'cvs_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'scores' }
                             ]
                         },
-                        'permutation_importance': defaultInfos['permutation_importance'],
+                        'permutation_importance': {
+                            name: 'permutation_importance',
+                            label: 'Permutation importance',
+                            import: 'from sklearn.inspection import permutation_importance',
+                            code: '${importance_allocate} = vp_create_permutation_importances(${model}, ${importance_featureData}, ${importance_targetData}${scoring}${sort})',
+                            description: 'Permutation importance for feature evaluation.',
+                            options: [
+                                { name: 'importance_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X_train' },
+                                { name: 'importance_targetData', label: 'Target Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'y_train' },
+                                { name: 'scoring', component: ['option_suggest'], usePair: true, type: 'text', 
+                                    options: [
+                                        'explained_variance', 'max_error', 'neg_mean_absolute_error', 'neg_mean_squared_error', 'neg_root_mean_squared_error',
+                                        'neg_mean_squared_log_error', 'neg_median_absolute_error', 'r2', 'neg_mean_poisson_deviance', 'neg_mean_gamma_deviance',
+                                        'neg_mean_absolute_percentage_error'
+                                    ] },
+                                { name: 'sort', label: 'Sort data', component: ['bool_checkbox'], value: true, usePair: true },
+                                { name: 'importance_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'importances' }
+                            ]
+                        },
+                        'plot_permutation_importance': {
+                            name: 'plot_permutation_importance',
+                            label: 'Plot permutation importance',
+                            import: 'from sklearn.inspection import permutation_importance',
+                            code: 'vp_plot_permutation_importances(${model}, ${importance_featureData}, ${importance_targetData}${scoring}${sort}${top_count})',
+                            description: 'Permutation importance for feature evaluation.',
+                            options: [
+                                { name: 'importance_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X_train' },
+                                { name: 'importance_targetData', label: 'Target Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'y_train' },
+                                { name: 'scoring', component: ['option_suggest'], usePair: true, type: 'text', 
+                                    options: [
+                                        'explained_variance', 'max_error', 'neg_mean_absolute_error', 'neg_mean_squared_error', 'neg_root_mean_squared_error',
+                                        'neg_mean_squared_log_error', 'neg_median_absolute_error', 'r2', 'neg_mean_poisson_deviance', 'neg_mean_gamma_deviance',
+                                        'neg_mean_absolute_percentage_error'
+                                    ] },
+                                { name: 'sort', label: 'Sort data', component: ['bool_checkbox'], value: true, usePair: true },
+                                { name: 'top_count', label: 'Top count', component: ['input_number'], min: 0, usePair: true }
+                            ]
+                        },
                         'Coefficient': {
                             name: 'coef_',
                             label: 'Coefficient',
@@ -754,7 +850,44 @@ define([
                                 { name: 'auc_targetData', label: 'Target Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'y_test' }
                             ]
                         },
-                        'permutation_importance': defaultInfos['permutation_importance']
+                        'permutation_importance': {
+                            name: 'permutation_importance',
+                            label: 'Permutation importance',
+                            import: 'from sklearn.inspection import permutation_importance',
+                            code: '${importance_allocate} = vp_create_permutation_importances(${model}, ${importance_featureData}, ${importance_targetData}${scoring}${sort})',
+                            description: 'Permutation importance for feature evaluation.',
+                            options: [
+                                { name: 'importance_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X_train' },
+                                { name: 'importance_targetData', label: 'Target Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'y_train' },
+                                { name: 'scoring', component: ['option_suggest'], usePair: true, type: 'text', 
+                                    options: [
+                                        'accuracy', 'balanced_accuracy', 'top_k_accuracy', 'average_precision', 'neg_brier_score',
+                                        'f1', 'f1_micro', 'f1_macro', 'f1_weighted', 'f1_samples', 'neg_log_loss', 'precision', 'recall', 'jaccard', 
+                                        'roc_auc', 'roc_auc_ovr', 'roc_auc_ovo', 'roc_auc_ovr_weighted', 'roc_auc_ovo_weighted'
+                                    ] },
+                                { name: 'sort', label: 'Sort data', component: ['bool_checkbox'], value: true, usePair: true },
+                                { name: 'importance_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'importances' }
+                            ]
+                        },
+                        'plot_permutation_importance': {
+                            name: 'plot_permutation_importance',
+                            label: 'Plot permutation importance',
+                            import: 'from sklearn.inspection import permutation_importance',
+                            code: 'vp_plot_permutation_importances(${model}, ${importance_featureData}, ${importance_targetData}${scoring}${sort}${top_count})',
+                            description: 'Permutation importance for feature evaluation.',
+                            options: [
+                                { name: 'importance_featureData', label: 'Feature Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X_train' },
+                                { name: 'importance_targetData', label: 'Target Data', component: ['data_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'y_train' },
+                                { name: 'scoring', component: ['option_suggest'], usePair: true, type: 'text', 
+                                    options: [
+                                        'accuracy', 'balanced_accuracy', 'top_k_accuracy', 'average_precision', 'neg_brier_score',
+                                        'f1', 'f1_micro', 'f1_macro', 'f1_weighted', 'f1_samples', 'neg_log_loss', 'precision', 'recall', 'jaccard', 
+                                        'roc_auc', 'roc_auc_ovr', 'roc_auc_ovo', 'roc_auc_ovr_weighted', 'roc_auc_ovo_weighted'
+                                    ] },
+                                { name: 'sort', label: 'Sort data', component: ['bool_checkbox'], value: true, usePair: true },
+                                { name: 'top_count', label: 'Top count', component: ['input_number'], min: 0, usePair: true }
+                            ]
+                        },
                     }
 
                     // feature importances
