@@ -31,6 +31,7 @@ define([
             /** Write codes executed before rendering */
             this.config.sizeLevel = 2;
             this.config.checkModules = ['pd'];
+            this.config.helpview = true;
 
             this.howList = [
                 { label: 'Inner', value: 'inner', desc: 'Inner join' },
@@ -127,6 +128,8 @@ define([
                 // clear user option
                 $(that.wrapSelector('#vp_bdUserOption')).val('');
                 that.state.userOption = '';
+
+                that.setHelpContent('_vp_pd.' + type);
             });
 
             //====================================================================
@@ -336,7 +339,7 @@ define([
 
         renderDataPage(renderedText, isHtml = true) {
             var tag = new com_String();
-            tag.appendFormatLine('<div class="{0} vp-close-on-blur vp-scrollbar">', 'vp_rendered_html'); // 'rendered_html' style from jupyter output area
+            tag.appendFormatLine('<div class="{0} vp-close-on-blur">', 'vp_rendered_html'); // 'rendered_html' style from jupyter output area
             if (isHtml) {
                 tag.appendLine(renderedText);
             } else {
@@ -352,7 +355,7 @@ define([
             // if not, get output of all data in selected pandasObject
             vpKernel.execute(code).then(function(resultObj) {
                 let { msg } = resultObj;
-                if (msg.content.data) {
+                if (msg.content && msg.content.data) {
                     var htmlText = String(msg.content.data["text/html"]);
                     var codeText = String(msg.content.data["text/plain"]);
                     if (htmlText != 'undefined') {
@@ -365,20 +368,20 @@ define([
                     }
                 } else {
                     var errorContent = '';
-                    if (msg.content.ename) {
-                        errorContent = com_util.templateForErrorBox(msg.content.ename, msg.content.evalue);
+                    if (msg.content && msg.content.ename) {
+                        errorContent = com_util.templateForErrorBox(msg.content.ename, msg.content?.evalue);
                     }
+                    vpLog.display(VP_LOG_TYPE.ERROR, msg.content?.ename, msg.content?.evalue, msg.content);
                     that.renderDataPage(errorContent);
-                    vpLog.display(VP_LOG_TYPE.ERROR, msg.content.ename, msg.content.evalue, msg.content);
                 }
             }).catch(function(resultObj) {
                 let { msg } = resultObj;
                 var errorContent = '';
-                if (msg.content.ename) {
-                    errorContent = com_util.templateForErrorBox(msg.content.ename, msg.content.evalue);
+                if (msg.content && msg.content.ename) {
+                    errorContent = com_util.templateForErrorBox(msg.content.ename, msg.content?.evalue);
                 }
+                vpLog.display(VP_LOG_TYPE.ERROR, msg.content?.ename, msg.content?.evalue, msg.content);
                 that.renderDataPage(errorContent);
-                vpLog.display(VP_LOG_TYPE.ERROR, msg.content.ename, msg.content.evalue, msg.content);
             });
         }
 
@@ -392,6 +395,8 @@ define([
                 $(this.wrapSelector('#vp_bdWithoutColumn')).hide();
             }
 
+            this.setHelpContent('_vp_pd.' + this.state.type);
+
             this.loadVariableList();
         }
 
