@@ -31,7 +31,7 @@ define([
             super._init();
             /** Write codes executed before rendering */
             this.config.dataview = false;
-            this.config.sizeLevel = 4;
+            this.config.sizeLevel = 5;
             this.config.dataview = false;
             this.config.runButton = false;
             this.config.checkModules = ['pd', 'plt'];
@@ -826,11 +826,11 @@ define([
             }).catch(function(resultObj) {
                 let { msg } = resultObj;
                 var errorContent = '';
-                if (msg.content.ename) {
-                    errorContent = com_util.templateForErrorBox(msg.content.ename, msg.content.evalue, msg.content.detail);
+                if (msg.content && msg.content.ename) {
+                    errorContent = com_util.templateForErrorBox(msg.content.ename, msg.content?.evalue, msg.content?.detail);
                 }
+                vpLog.display(VP_LOG_TYPE.ERROR, msg.content?.ename, msg.content?.evalue, msg.content);
                 $(variablePreviewTag).html(errorContent);
-                vpLog.display(VP_LOG_TYPE.ERROR, msg.content.ename, msg.content.evalue, msg.content);
                 that.loading = false;
             });
     
@@ -886,18 +886,18 @@ define([
                     }
                 } else {
                     var errorContent = '';
-                    if (msg.content.ename) {
+                    if (msg.content && msg.content.ename) {
                         errorContent = com_util.templateForErrorBox(msg.content.ename, msg.content.evalue, msg.content.detail);
                     }
                     $infoPreviewTag.html(errorContent);
-                    vpLog.display(VP_LOG_TYPE.ERROR, msg.content.ename, msg.content.evalue, msg.content);
+                    vpLog.display(VP_LOG_TYPE.ERROR, msg.content?.ename, msg.content?.evalue, msg.content);
                 }
             }).catch(function(resultObj) {
                 let { msg, ename, evalue } = resultObj;
                 var errorContent = '';
                 if (msg && msg?.content?.ename) {
                     errorContent = com_util.templateForErrorBox(msg.content.ename, msg.content.evalue, msg.content.detail);
-                    vpLog.display(VP_LOG_TYPE.ERROR, msg.content.ename, msg.content.evalue, msg.content);
+                    vpLog.display(VP_LOG_TYPE.ERROR, msg.content?.ename, msg.content?.evalue, msg.content);
                 } else if (ename && evalue) {
                     errorContent = com_util.templateForErrorBox(ename, evalue);
                     vpLog.display(VP_LOG_TYPE.ERROR, ename, evalue, resultObj);
