@@ -343,10 +343,13 @@ define([
             $(this.wrapSelector('.select-row .vp-ds-select-box.left')).on('scroll', function() {
                 if ($(this).scrollTop() + $(this).innerHeight() >= ($(this)[0].scrollHeight - 2)) {
                     let scrollPos = $(this).scrollTop();
+                    if (that.state.rowLimit > that.state.rowList.length){
+                        return; // Prevents scroll from being fixed downwards
+                    }
                     let start = that.state.rowLimit;
                     let end = start + 10;
                     let subsetVariable = com_util.formatString('{0}.iloc[{1}:{2}]', that.state.pandasObject, start, end);
-                    vpKernel.getRowList(subsetVariable).then(function (resultObj) {
+                    vpKernel.getRowList(subsetVariable, start).then(function (resultObj) {
                         let { result } = resultObj;
                         var { list:rowList } = JSON.parse(result);
                         rowList = rowList.map(function (x) {
@@ -361,9 +364,9 @@ define([
                             rowList = rowList.map(function (x) {
                                 return {
                                     ...x,
-                                    label: x.location + '',
-                                    value: x.location + '',
-                                    code: x.location + '',
+                                    label: x.label + '',
+                                    value: x.value + '',
+                                    code: x.code + '',
                                 };
                             });
                         }
@@ -1810,6 +1813,10 @@ define([
                             rowSelection.append(')');
                         } else {
                             rowSelection.appendFormat('({0}', varName);
+                            if (colName == '.index') {
+                                // index
+                                rowSelection.append('.index');
+                            }
                             oper && rowSelection.appendFormat(' {0}', oper);
                             if (cond) {
                                 // condition value as text
@@ -1863,7 +1870,7 @@ define([
                             var colList = [];
                             for (var i = 0; i < colTags.length; i++) {
                                 var colValue = $(colTags[i]).data('code');
-                                if (colValue) {
+                                if (colValue !== undefined) {
                                     colList.push(colValue);
                                 }
                             }
@@ -1873,7 +1880,7 @@ define([
                                 $(this.wrapSelector('.' + VP_DS_TO_FRAME)).parent().show();
     
                                 // to frame
-                                if (this.state.toFrame) {
+                                if (this.state.toFrame === true) {
                                     colSelection.appendFormat('[{0}]', colList.toString());
                                     this.state.returnType = 'DataFrame';
                                 } else {
